'''
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
'''

from resource_management.libraries.functions import format
from resource_management.libraries.script.script import Script
import os
import os.path
from resource_management.libraries.functions.default import default
from resource_management.libraries.functions.substitute_vars import substitute_vars




# config object that holds the configurations declared in the -config.xml file
config = Script.get_config()

# RPM versioning support
# rpm_version = default("/configurations/cluster-env/rpm_version", None)

# store the ambari stack service dir
service_package_folder = '/var/lib/ambari-agent/cache/stacks/HDP/2.1/services/SMARTSENSE/package'
hst_log_dir = '/var/log/hst'
activity_log_dir = '/var/log/smartsense-activity'
ambari_service_log = os.path.join(hst_log_dir, 'ambari-service.log')
hst_conf_dir = '/etc/hst/conf'
activity_conf_dir = '/etc/smartsense-activity/conf'
log4j_conf_file = os.path.join(hst_conf_dir, 'log4j.properties');
activity_log4j_conf_file = os.path.join(activity_conf_dir, 'log4j.properties');
hst_win_service_name = 'hst'
hst_pid_dir = '/var/run/hst'
activity_analyzer_pid_dir = '/var/run/smartsense-activity-analyzer'
activity_explorer_pid_dir = '/var/run/smartsense-activity-explorer'
server_conf_file_name = 'hst-server.ini'
activity_analyzer_conf_file_name = 'activity.ini'
agent_conf_file_name = 'hst-agent.ini'
hst_install_home = '/usr/hdp/share/hst'
hst_agent_home = os.path.join(hst_install_home, 'hst-agent')
hst_server_home = os.path.join(hst_install_home, 'hst-server')
capture_levels_json = os.path.join(hst_conf_dir, 'capture_levels.json')
anonymization_rules_json = os.path.join(hst_conf_dir, 'anonymization_rules.json')
smartsense_packages = ["smartsense-hst"]
hst_shell_cmds_dir = os.path.join(service_package_folder, 'files')
hst_view_dir = os.path.join(hst_shell_cmds_dir, 'view')
hst_view_conf_xml = os.path.join(hst_view_dir, 'view.xml')
hst_default_view_template = os.path.join(hst_view_dir, 'view_default.xml')
hst_instance_view_template = os.path.join(hst_view_dir, 'view_instance.xml')
hst_view_jar_file_name = 'smartsense*view*.jar'
hst_view_jar_file_path = os.path.join(hst_view_dir, hst_view_jar_file_name)
hst_view_jar = os.path.join(hst_view_dir, hst_view_jar_file_name)
ambari_view_dir = "/var/lib/ambari-server/resources/views"
ambari_agent_data_dir = "/var/lib/ambari-agent/data/"
install_view_tmp_dir = "/tmp/smartsense-view/"


# Env properties
if 'hst-env' in config['configurations']:
    if 'hst_pid_dir' in config['configurations']['hst-env']:
        hst_pid_dir = config['configurations']['hst-env']['hst_pid_dir']
    if 'hst_log_dir' in config['configurations']['hst-env']:
        hst_log_dir = config['configurations']['hst-env']['hst_log_dir']
    if 'hst_conf_dir' in config['configurations']['hst-env']:
        hst_conf_dir = config['configurations']['hst-env']['hst_conf_dir']


# Env properties
if 'hst-log4j' in config['configurations']:
    if 'hst_log_dir' in config['configurations']['hst-log4j']:
        hst_log_dir = config['configurations']['hst-log4j']['hst_log_dir']

# Path to HST PID file.
hst_pid_file = os.path.join(hst_pid_dir, 'hst-server.pid')
activity_analyzer_pid_file = os.path.join(activity_analyzer_pid_dir, 'activity-analyzer.pid')
activity_explorer_pid_file = os.path.join(activity_explorer_pid_dir, 'activity-explorer.pid')

hst_server_host = 'localhost'
if 'clusterHostInfo' in config and 'hst_server_hosts' in config['clusterHostInfo']:
    hst_server_host = config['clusterHostInfo']['hst_server_hosts'][0]


# Env properties
if 'activity-log4j' in config['configurations']:
    if 'activity_log_dir' in config['configurations']['activity-log4j']:
        activity_log_dir = config['configurations']['activity-log4j']['activity_log_dir']

activity_explorer_home = os.path.join(hst_install_home, "activity-explorer")
activity_analyzer_home = os.path.join(hst_install_home, "activity-analyzer")
activity_explorer_notebook_dir = "/var/lib/smartsense/activity-explorer/notebook"



hst_tool_cleanup_directories = [
                                '/etc/hst',
                                '/var/log/hst',
                                '/var/run/hst',
                                hst_log_dir,
                                hst_conf_dir,
                                hst_pid_dir
                                ]

hst_view_instance_cleanup_directories = [
                                         os.path.join(ambari_view_dir, "work", "SMARTSENSE*"),
                                         os.path.join(ambari_view_dir, "work", "HORTONWORKS_SMARTSENSE*")
                                         ]

hst_view_cleanup_directories = [
                                os.path.join(ambari_view_dir, "smartsense*")
                                ]

ambari_service_server_cleanup_directories = [
                                  "/var/lib/ambari-server/resources/stacks/HDP/2.1/services/SMARTSENSE"
                                 ]

ambari_service_agent_cleanup_directories = [
                                  "/var/lib/ambari-agent/cache/stacks/HDP/2.1/services/SMARTSENSE"
                                 ]

server_owned_dirs = [
                    '/etc/hst',
                    '/var/log/hst',
                    '/var/run/hst',
                    hst_log_dir,
                    hst_conf_dir,
                    hst_pid_dir,
                    "/var/lib/smartsense",
                    "/var/lib/smartsense/hst-common",
                    "/var/lib/smartsense/hst-server"                    
                    ]
activity_analyzer_owned_dirs = [
                    "/var/lib/smartsense/activity-analyzer",
                    '/etc/smartsense-activity',
                    '/var/log/smartsense-activity',
                    '/var/run/smartsense-activity-analyzer',
                    activity_log_dir,
                    activity_conf_dir,
                    activity_analyzer_pid_dir
                    ]
activity_explorer_owned_dirs = [
                    "/var/lib/smartsense/activity-explorer",
                    '/etc/smartsense-activity',
                    '/var/log/smartsense-activity',
                    '/var/run/smartsense-activity-explorer',
                    activity_log_dir,
                    activity_conf_dir,
                    activity_explorer_pid_dir
                    ]

agent_owned_dirs = [
                    '/etc/hst',
                    '/var/log/hst',
                    hst_log_dir,
                    hst_conf_dir,
                    "/var/lib/smartsense/hst-agent"                    
                    ]

if ('hst-server-conf' in config['configurations'] and 'server.storage.dir' in config['configurations']['hst-server-conf']) :
    hst_tool_cleanup_directories.append(config['configurations']['hst-server-conf']['server.storage.dir'])
    server_owned_dirs.append(config['configurations']['hst-server-conf']['server.storage.dir'])

if ('hst-server-conf' in config['configurations'] and 'server.tmp.dir' in config['configurations']['hst-server-conf']) :
    hst_tool_cleanup_directories.append(config['configurations']['hst-server-conf']['server.tmp.dir'])
    server_owned_dirs.append(config['configurations']['hst-server-conf']['server.tmp.dir'])

if ('hst-agent-conf' in config['configurations'] and 'server.tmp_dir' in config['configurations']['hst-agent-conf']) :
    hst_tool_cleanup_directories.append(config['configurations']['hst-agent-conf']['agent.tmp_dir'])
    agent_owned_dirs.append(config['configurations']['hst-agent-conf']['agent.tmp_dir'])


# Configurations
hst_common_config = None
if ('hst-common-conf' in config['configurations']) :
    hst_common_config = config['configurations']['hst-common-conf']

hst_server_config = None
if ('hst-server-conf' in config['configurations']) :
    hst_server_config = config['configurations']['hst-server-conf']

activity_analyzer_config = None
if ('activity-conf' in config['configurations']) :
    activity_analyzer_config = config['configurations']['activity-conf']

hst_agent_config = None
if ('hst-agent-conf' in config['configurations']) :
    hst_agent_config = config['configurations']['hst-agent-conf']


security_enabled = False 
if 'cluster-env' in config['configurations'] and 'security_enabled' in config['configurations']['cluster-env']:
    if (str(config['configurations']['cluster-env']['security_enabled']).upper() == 'TRUE'):
        security_enabled = True


java_home = config['hostLevelParams']['java_home']
phoenix_zk_quorum = "localhost"
phoenix_zk_port = 61181
phoenix_zk_node = "/hbase"

if "ams-hbase-site" in config['configurations'] and 'hbase.zookeeper.property.clientPort' in config['configurations']['ams-hbase-site']:
    phoenix_zk_port = config['configurations']['ams-hbase-site']['hbase.zookeeper.property.clientPort'] 
    
if "ams-hbase-site" in config['configurations'] and 'hbase.zookeeper.quorum' in config['configurations']['ams-hbase-site']:
    phoenix_zk_quorum = config['configurations']['ams-hbase-site']['hbase.zookeeper.quorum'] 

if "ams-hbase-site" in config['configurations'] and 'zookeeper.znode.parent' in config['configurations']['ams-hbase-site']:
    phoenix_zk_node = config['configurations']['ams-hbase-site']['zookeeper.znode.parent'] 


is_ams_hbase_distributed = False 

if 'ams-hbase-site' in config['configurations'] and 'hbase.cluster.distributed' in config['configurations']['ams-hbase-site']:
    if (str(config['configurations']['ams-hbase-site']['hbase.cluster.distributed']).upper() == 'TRUE'):  
        is_ams_hbase_distributed = True
    
is_ams_hbase_secured = False

if (is_ams_hbase_distributed == True and security_enabled == True) :
    is_ams_hbase_secured = True

if phoenix_zk_quorum.startswith('{{'):
    if is_ams_hbase_distributed == False:
        if 'metrics_collector_hosts' in config['clusterHostInfo']: 
            phoenix_zk_quorum = config['clusterHostInfo']['metrics_collector_hosts'][0]
        else:
            phoenix_zk_quorum = 'localhost'
    else:
        if 'zookeeper_hosts' in config['clusterHostInfo']: 
            phoenix_zk_quorum = ",".join(config['clusterHostInfo']['zookeeper_hosts'])
        else:
            if 'metrics_collector_hosts' in config['clusterHostInfo']: 
                phoenix_zk_quorum = config['clusterHostInfo']['metrics_collector_hosts'][0]
            else:
                phoenix_zk_quorum = 'localhost'

if str(phoenix_zk_port).startswith('{{'):
    if is_ams_hbase_distributed == False:
        phoenix_zk_port = 61181
    else:
        if 'zoo.cfg' in config['configurations'] and 'clientPort' in config['configurations']['zoo.cfg']:
            phoenix_zk_port = config['configurations']['zoo.cfg']['clientPort']
        else:
            phoenix_zk_port = 2181

if phoenix_zk_node.startswith('{{'):
    if is_ams_hbase_distributed == False:
      phoenix_zk_node = "/ams-hbase-unsecure"
    else:
        if is_ams_hbase_secured == True: 
            phoenix_zk_node = "/ams-hbase-secure"
        else:
            phoenix_zk_node = "/ams-hbase-unsecure"


activity_analyzer_keytab = "/etc/security/keytabs/activity-analyzer.headless.keytab"
activity_analyzer_principal = "activity-analyzer@EXAMPLE.COM"
activity_explorer_keytab = "/etc/security/keytabs/activity-explorer.headless.keytab"
activity_explorer_principal = "activity-explorer@EXAMPLE.COM"
 
if is_ams_hbase_secured == True and 'activity-conf' in config['configurations']: 
    if 'global.activity.analyzer.user.keytab' in config['configurations']['activity-conf']:
        activity_analyzer_keytab = config['configurations']['activity-conf']['global.activity.analyzer.user.keytab']
    if 'global.activity.analyzer.user.principal' in config['configurations']['activity-conf']:
        activity_analyzer_principal = config['configurations']['activity-conf']['global.activity.analyzer.user.principal']
    if 'activity.explorer.user.keytab' in config['configurations']['activity-conf']:
        activity_explorer_keytab = config['configurations']['activity-conf']['activity.explorer.user.keytab']
    if 'activity.explorer.user.principal' in config['configurations']['activity-conf']:
        activity_explorer_principal = config['configurations']['activity-conf']['activity.explorer.user.principal']

activity_analyzer_jdbc_url = "jdbc:phoenix:" + str(phoenix_zk_quorum) + ":" + str(phoenix_zk_port) + ":" + str(phoenix_zk_node)
activity_explorer_jdbc_url = activity_analyzer_jdbc_url
if (is_ams_hbase_secured == True):
    activity_analyzer_jdbc_url = str(activity_analyzer_jdbc_url) + ":" + str(activity_analyzer_principal) + ":" + str(activity_analyzer_keytab)
    activity_explorer_jdbc_url = str(activity_explorer_jdbc_url) + ":" + str(activity_explorer_principal) + ":" + str(activity_explorer_keytab)

ams_jdbc_url = activity_explorer_jdbc_url



hdp_version = "2.0.0.0-0000"
if 'hostLevelParams' in config and 'stack_version' in config['hostLevelParams']:
    # e.g. 2.3
    stack_version_unformatted = str(config['hostLevelParams']['stack_version'])
    # e.g. 2.3.0.0
    try:
        from resource_management.libraries.functions.version import format_hdp_stack_version
        hdp_stack_version = format_hdp_stack_version(stack_version_unformatted)
    except ImportError:
        from resource_management.libraries.functions.version import format_stack_version
        hdp_stack_version = format_stack_version(stack_version_unformatted)
    # e.g. 2.3.0.0-2130
    full_version = default("/commandParams/version", None)
    hdp_version = full_version

ams_hbase_conf_dir = "/etc/ams-hbase/conf"
ams_user = "ams"
ams_user_group = "hadoop"
if ('configurations' in config and 'ams-env' in  config['configurations'] and 'ambari_metrics_user' in config['configurations']['ams-env']):
    ams_user = config['configurations']['ams-env']['ambari_metrics_user']

if ('configurations' in config and 'cluster-env' in  config['configurations'] and 'user_group' in config['configurations']['cluster-env']):
    ams_user_group = config['configurations']['cluster-env']["user_group"]
    
    
ams_phoenix_max_global_mem_percent = default('/configurations/ams-site/phoenix.query.maxGlobalMemoryPercentage', '20')
ams_phoenix_client_spool_dir = default('/configurations/ams-site/phoenix.spool.directory', '/tmp')
ams_phoenix_client_spool_dir = substitute_vars(ams_phoenix_client_spool_dir, config['configurations']['ams-hbase-site'])
